| Title: | Use Czech labour market survey data |
|---|---|
| Description: | Retrieve and load data from the Czech Information System on Average Earnings (ISPV) at <https://www.ispv.cz>. |
| Authors: | Petr Bouchal [aut, cre] (ORCID: <https://orcid.org/0000-0002-0471-716X>) |
| Maintainer: | Petr Bouchal <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0.9000 |
| Built: | 2026-05-13 06:49:29 UTC |
| Source: | https://github.com/petrbouchal/ispv |
Used in pv_reg_*() to add proper region IDs and names.
krajekraje
A data frame with 14 rows and 4 variables:
kraj_id_ispvcharacter. Internal region code, appears in Excel file name
kraj_idcharacter. non-NUTS ID of kraj (region, NUTS3).
kraj_namecharacter. Czech name of kraj (region, NUTS3).
kraj_id_nuts3character. NUTS ID of kraj (region, NUTS3)..
Load country-wide data by gender and age (age in 6 bins)
pv_cr_monthlypay_age_gender(path, sheet = 2)pv_cr_monthlypay_age_gender(path, sheet = 2)
path |
path(s) to file(s), Will be file with "CR_YYQD and either "PLS" or "MZS" in the name. |
sheet |
sheet number; you should be able to leave this as default (2) if using files downloaded from ISPV |
a tibble
pv_cr_monthlypay_age_gender(system.file("extdata", "CR_204_MZS.xlsx", package = "ispv")) pv_cr_monthlypay_age_gender(system.file("extdata", "CR_204_PLS.xlsx", package = "ispv"))pv_cr_monthlypay_age_gender(system.file("extdata", "CR_204_MZS.xlsx", package = "ispv")) pv_cr_monthlypay_age_gender(system.file("extdata", "CR_204_PLS.xlsx", package = "ispv"))
Loads data on monthly earnings by education level from one or more local Excel files downloaded from ISPV links retrieved by pv_list_reg().
pv_cr_monthlypay_education(path, sheet = 3)pv_cr_monthlypay_education(path, sheet = 3)
path |
path(s) to file(s), Will be file with "CR_YYQD and either "PLS" or "MZS" in the name. |
sheet |
sheet number; you should be able to leave this as default (3) if using files downloaded from ISPV |
a tibble
pv_cr_monthlypay_education(system.file("extdata", "CR_204_PLS.xlsx", package = "ispv")) pv_cr_monthlypay_education(system.file("extdata", "CR_204_MZS.xlsx", package = "ispv"))pv_cr_monthlypay_education(system.file("extdata", "CR_204_PLS.xlsx", package = "ispv")) pv_cr_monthlypay_education(system.file("extdata", "CR_204_MZS.xlsx", package = "ispv"))
Load country-wide data by ISCO (profession classification) at 4 and 5 digits
pv_cr_monthlypay_isco(path, sheet = 1)pv_cr_monthlypay_isco(path, sheet = 1)
path |
path(s) to file(s), Will be file with "CR_YYQD and either "PLS" or "MZS" in the name. |
sheet |
which sheet to open. Will be 1 (the default) in files with only one sheet ("CR_204_MZS_M8r.xlsx") and 7 in comprehensive file ("CR_204_MZS.xlsx") |
a tibble
pv_cr_monthlypay_isco(system.file("extdata", "CR_204_MZS_M8r.xlsx", package = "ispv"), 1) pv_cr_monthlypay_isco(system.file("extdata", "CR_204_MZS.xlsx", package = "ispv"), 7) pv_cr_monthlypay_isco(system.file("extdata", "CR_204_PLS_M8r.xlsx", package = "ispv"), 1) pv_cr_monthlypay_isco(system.file("extdata", "CR_204_PLS.xlsx", package = "ispv"), 7)pv_cr_monthlypay_isco(system.file("extdata", "CR_204_MZS_M8r.xlsx", package = "ispv"), 1) pv_cr_monthlypay_isco(system.file("extdata", "CR_204_MZS.xlsx", package = "ispv"), 7) pv_cr_monthlypay_isco(system.file("extdata", "CR_204_PLS_M8r.xlsx", package = "ispv"), 1) pv_cr_monthlypay_isco(system.file("extdata", "CR_204_PLS.xlsx", package = "ispv"), 7)
Load country-wide data by NACE (single-letter industry codes)
pv_cr_monthlypay_nace(path, sheet = 5)pv_cr_monthlypay_nace(path, sheet = 5)
path |
path(s) to file(s), Will be file with "CR_YYQD and either "PLS" or "MZS" in the name. |
sheet |
sheet number; you should be able to leave this as default (5) if using files downloaded from ISPV |
a tibble
pv_cr_monthlypay_nace(system.file("extdata", "CR_204_MZS.xlsx", package = "ispv")) pv_cr_monthlypay_nace(system.file("extdata", "CR_204_PLS.xlsx", package = "ispv"))pv_cr_monthlypay_nace(system.file("extdata", "CR_204_MZS.xlsx", package = "ispv")) pv_cr_monthlypay_nace(system.file("extdata", "CR_204_PLS.xlsx", package = "ispv"))
This function scrapes the relevant year's archive page for links to Excel files with national data and returns the result in a tibble.
pv_list_cr(year = NULL, base_url = NULL, user_agent = NULL)pv_list_cr(year = NULL, base_url = NULL, user_agent = NULL)
year |
Year, defaults to scraping page for latest available data. String or numeric in YYYY format of length >= 1 |
base_url |
base url, defaults to https://ispv.cz |
user_agent |
User agent string, defaults to package URL on Github (https://github.com/petrbouchal/ispv). |
a tibble with file name, URL and year. File name can be used to determine the time period and region.
## Not run: pv_list_reg(year = 2019:2020) ## End(Not run)## Not run: pv_list_reg(year = 2019:2020) ## End(Not run)
This function scrapes the relevant year's archive page for links to Excel files with regional data and returns the result in a tibble.
pv_list_reg(year = NULL, base_url = NULL, user_agent = NULL)pv_list_reg(year = NULL, base_url = NULL, user_agent = NULL)
year |
Year, defaults to scraping page for latest available data. String or numeric in YYYY format of length >= 1. |
base_url |
base url, defaults to https://ispv.cz |
user_agent |
User agent string, defaults to package URL on Github (https://github.com/petrbouchal/ispv). |
a tibble with file name, URL and year. File name can be used to determine the time period and region.
## Not run: pv_list_reg(year = 2019:2020) ## End(Not run)## Not run: pv_list_reg(year = 2019:2020) ## End(Not run)
Load ISPV Excel files with regional data on monthly earnings by ISCO code
pv_reg_monthlypay_age_gender(path, sheet = 2)pv_reg_monthlypay_age_gender(path, sheet = 2)
path |
path(s) to file(s), Will be file with "Reg_YYQ" and either "PLS" or "MZS" in the name. |
sheet |
sheet number; you should be able to leave this as default (2) if using files downloaded from ISPV |
a tibble
pv_reg_monthlypay_age_gender(system.file("extdata", "Kar_204_pls.xlsx", package = "ispv")) pv_reg_monthlypay_age_gender(system.file("extdata", "Kar_204_mzs.xlsx", package = "ispv"))pv_reg_monthlypay_age_gender(system.file("extdata", "Kar_204_pls.xlsx", package = "ispv")) pv_reg_monthlypay_age_gender(system.file("extdata", "Kar_204_mzs.xlsx", package = "ispv"))
Loads data on monthly earnings by education level from one or more local Excel files downloaded from ISPV links retrieved by pv_list_reg().
pv_reg_monthlypay_education(path, sheet = 2)pv_reg_monthlypay_education(path, sheet = 2)
path |
path(s) to file(s), Will be file with "Reg_YYQ" and either "PLS" or "MZS" in the name. |
sheet |
sheet number; you should be able to leave this as default (2) if using files downloaded from ISPV |
a tibble
pv_reg_monthlypay_education(system.file("extdata", "Kar_204_pls.xlsx", package = "ispv")) pv_reg_monthlypay_education(system.file("extdata", "Kar_204_mzs.xlsx", package = "ispv"))pv_reg_monthlypay_education(system.file("extdata", "Kar_204_pls.xlsx", package = "ispv")) pv_reg_monthlypay_education(system.file("extdata", "Kar_204_mzs.xlsx", package = "ispv"))
Loads data on monthly earnings by ISCO code from one or more local Excel files downloaded from ISPV links retrieved by pv_list_reg().
pv_reg_monthlypay_isco4(path, sheet = 4)pv_reg_monthlypay_isco4(path, sheet = 4)
path |
path(s) to file(s), Will be file with "Reg_YYQ" and either "PLS" or "MZS" in the name. |
sheet |
sheet number; you should be able to leave this as default (4) if using files downloaded from ISPV |
The function returns a data frame with 22 variables. All earnings are monthly gross in CZK.
kraj_id_ispvcharacter. Internal region code, appears in Excel file name
filecharacter. File from which this row was read.
isco4_fullcharacter. 4-digit ISCO (occupation) code with Czech ISCO category name. CZSO codelist number 5708
fte_thousdouble. Thousand FTEs in this ISCO-4 category - converted to FTE by months paid.
pay_mediandouble. Median monthly earnings.
pay_d1double. 1st decile monthly earnings.
pay_q1double. 1st quartile monthly earnings.
pay_q3double. 3rd quartile monthly earnings.
pay_d9double. 9th decline monthly earnings.
pay_meandouble. Mean earnings.
bonus_percdouble. Bonuses ("odměny") as share of pay, as decimal
supplements_percdouble. Supplements ("příplatky") as share of pay, as decimal.
compensation_percdouble. Compensation ("náhrady") as share of pay, as decimal.
hours_per_monthdouble. Monthly hours worked.
sferacharacter. Sphere - salary (pls) or wage (mzs), roughly equals public or private sector
periodcharacter. Time period as appears in file name, e.g. 204 is Q4 of 2020. Regional data only comes in Q4, i.e. for full year.
yearcharacter. Year, as 4-digit character vector
isco4_idcharacter. 4-digit ISCO code.
isco4_namecharacter. Czech name of 4-digit ISCO category
kraj_idcharacter. non-NUTS ID of kraj (region, NUTS3).
kraj_namecharacter. Czech name of kraj (region, NUTS3).
kraj_id_nuts3character. NUTS ID of kraj (region, NUTS3)..
a tibble, see Format for details.
pv_reg_monthlypay_isco4(system.file("extdata", "Kar_204_mzs.xlsx", package = "ispv")) pv_reg_monthlypay_isco4(system.file("extdata", "Kar_204_pls.xlsx", package = "ispv"))pv_reg_monthlypay_isco4(system.file("extdata", "Kar_204_mzs.xlsx", package = "ispv")) pv_reg_monthlypay_isco4(system.file("extdata", "Kar_204_pls.xlsx", package = "ispv"))